@@ -19,7 +19,7 @@ use Exporter qw(import);
 
 @EXPORT_OK = qw(get_Z get_symbol get_name);
 @EXPORT    = qw();
-$VERSION   = '1.064';
+$VERSION   = '1.065';
 
 use subs qw(
 	_get_name_by_Z
@@ -69,126 +69,126 @@ $debug = 0;
 
 $Default_language = $Languages{'English'};
 
-
+# http://www.ptable.com/?lang=ja
 %names = (
-  1 => [ qw( Ydrogenhai Hydrogen 水素) ],
-  2 => [ qw( Eliumhai Helium ヘリウム) ],
-  3 => [ qw( Ithiumlai Lithium リチウム) ],
-  4 => [ qw( Erylliumbai Beryllium ベリリウム) ],
-  5 => [ qw( Oronbai Boron ホウ素) ],
-  6 => [ qw( Arboncai Carbon 炭素) ],
-  7 => [ qw( Itrogennai Nitrogen 窒素) ],
-  8 => [ qw( Xygenoai Oxygen 酸素) ],
-  9 => [ qw( Luorinefai Fluorine フッ素) ],
- 10 => [ qw( Eonnai Neon ネオン) ],
- 11 => [ qw( Odiumsai Sodium ナトリウム) ],
- 12 => [ qw( Agnesiummai Magnesium マグネシウム) ],
- 13 => [ qw( Luminiumaai Aluminium アルミニウム) ],
- 14 => [ qw( Iliconsai Silicon ケイ素) ],
- 15 => [ qw( Hosphoruspai Phosphorus リン) ],
- 16 => [ qw( Ulfursai Sulfur 硫黄) ],
- 17 => [ qw( Hlorinecai Chlorine 塩素) ],
- 18 => [ qw( Rgonaai Argon アルゴン) ],
- 19 => [ qw( Otassiumpai Potassium カリウム) ],
- 20 => [ qw( Alciumcai Calcium カルシウム) ],
- 21 => [ qw( Candiumsai Scandium スカンジウム) ],
- 22 => [ qw( Itaniumtai Titanium チタン) ],
- 23 => [ qw( Anadiumvai Vanadium バナジウム) ],
- 24 => [ qw( Hromiumcai Chromium クロム) ],
- 25 => [ qw( Anganesemai Manganese マンガン) ],
- 26 => [ qw( Roniai Iron 鉄) ],
- 27 => [ qw( Obaltcai Cobalt コバルト) ],
- 28 => [ qw( Ickelnai Nickel ニッケル) ],
- 29 => [ qw( Oppercai Copper 銅) ],
- 30 => [ qw( Inczai Zinc 亜鉛) ],
- 31 => [ qw( Alliumgai Gallium ガリウム) ],
- 32 => [ qw( Ermaniumgai Germanium ゲルマニウム) ],
- 33 => [ qw( Rsenicaai Arsenic ヒ素) ],
- 34 => [ qw( Eleniumsai Selenium セレン) ],
- 35 => [ qw( Rominebai Bromine 臭素) ],
- 36 => [ qw( Ryptonkai Krypton クリプトン) ],
- 37 => [ qw( Ubidiumrai Rubidium ルビジウム) ],
- 38 => [ qw( Trontiumsai Strontium ストロンチウム) ],
- 39 => [ qw( Ttriumyai Yttrium イットリウム) ],
- 40 => [ qw( Irconiumzai Zirconium ジルコニウム) ],
- 41 => [ qw( Iobiumnai Niobium ニオブ) ],
- 42 => [ qw( Olybdenummai Molybdenum モリブデン) ],
- 43 => [ qw( Echnetiumtai Technetium テクネチウム) ],
- 44 => [ qw( Utheniumrai Ruthenium ルテニウム) ],
- 45 => [ qw( Hodiumrai Rhodium ロジウム) ],
- 46 => [ qw( Alladiumpai Palladium パラジウム) ],
- 47 => [ qw( Ilversai Silver 銀) ],
- 48 => [ qw( Admiumcai Cadmium カドミウム) ],
- 49 => [ qw( Ndiumiai Indium インジウム) ],
- 50 => [ qw( Intai Tin スズ) ],
- 51 => [ qw( Ntimonyaai Antimony アンチモン) ],
- 52 => [ qw( Elluriumtai Tellurium テルル) ],
- 53 => [ qw( Odineiai Iodine ヨウ素) ],
- 54 => [ qw( Enonxai Xenon キセノン) ],
- 55 => [ qw( Esiumcai Cesium セシウム) ],
- 56 => [ qw( Ariumbai Barium バリウム) ],
- 57 => [ qw( Anthanumlai Lanthanum ランタン) ],
- 58 => [ qw( Eriumcai Cerium セリウム) ],
- 59 => [ qw( Raesodymiumpai Praseodymium ) ],
- 60 => [ qw( Eodymiumnai Neodymium ネオジム) ],
- 61 => [ qw( Romethiumpai Promethium プロメチウム) ],
- 62 => [ qw( Amariumsai Samarium サマリウム) ],
- 63 => [ qw( Uropiumeai Europium ユウロピウム) ],
- 64 => [ qw( Adoliniumgai Gadolinium ガドリニウム) ],
- 65 => [ qw( Erbiumtai Terbium テルビウム) ],
- 66 => [ qw( Ysprosiumdai Dysprosium ジスプロシウム) ],
- 67 => [ qw( Olmiumhai Holmium ホルミウム) ],
- 68 => [ qw( Rbiumeai Erbium エルビウム) ],
- 69 => [ qw( Huliumtai Thulium ツリウム) ],
- 70 => [ qw( Tterbiumyai Ytterbium イッテルビウム) ],
- 71 => [ qw( Utetiumlai Lutetium ルテチウム) ],
- 72 => [ qw( Afniumhai Hafnium ハフニウム) ],
- 73 => [ qw( Antalumtai Tantalum タンタル) ],
- 74 => [ qw( Ungstentai Tungsten タングステン) ],
- 75 => [ qw( Heniumrai Rhenium レニウム) ],
- 76 => [ qw( Smiumoai Osmium オスミウム) ],
- 77 => [ qw( Ridiumiai Iridium イリジウム) ],
- 78 => [ qw( Latinumpai Platinum 白金) ],
- 79 => [ qw( Oldgai Gold 金) ],
- 80 => [ qw( Ercurymai Mercury 水銀) ],
- 81 => [ qw( Halliumtai Thallium タリウム) ],
- 82 => [ qw( Eadlai Lead 鉛) ],
- 83 => [ qw( Ismuthbai Bismuth ビスマス) ],
- 84 => [ qw( Oloniumpai Polonium ポロニウム) ],
- 85 => [ qw( Statineaai Astatine アスタチン) ],
- 86 => [ qw( Adonrai Radon ラドン) ],
- 87 => [ qw( Ranciumfai Francium フランシウム) ],
- 88 => [ qw( Adiumrai Radium ラジウム) ],
- 89 => [ qw( Ctiniumaai Actinium アクチニウム) ],
- 90 => [ qw( Horiumtai Thorium トリウム) ],
- 91 => [ qw( Rotactiniumpai Protactinium プロトアクチニウム) ],
- 92 => [ qw( Raniumuai Uranium ウラン) ],
- 93 => [ qw( Eptuniumnai Neptunium ネプツニウム) ],
- 94 => [ qw( Lutoniumpai Plutonium プルトニウム) ],
- 95 => [ qw( Mericiumaai Americium アメリシウム) ],
- 96 => [ qw( Uriumcai Curium キュリウム) ],
- 97 => [ qw( Erkeliumbai Berkelium バークリウム) ],
- 98 => [ qw( Aliforniumcai Californium カリホルニウム) ],
- 99 => [ qw( Insteiniumeai Einsteinium アインスタイニウム) ],
-100 => [ qw( Ermiumfai Fermium フェルミウム) ],
-101 => [ qw( Endeleviummai Mendelevium メンデレビウム) ],
-102 => [ qw( Obeliumnai Nobelium ノーベリウム) ],
-103 => [ qw( Awerenciumlai Lawrencium ローレンシウム) ],
+  1 => [ qw( Ydrogenhai      Hydrogen      水素) ],
+  2 => [ qw( Eliumhai        Helium        ヘリウム) ],
+  3 => [ qw( Ithiumlai       Lithium       リチウム) ],
+  4 => [ qw( Erylliumbai     Beryllium     ベリリウム) ],
+  5 => [ qw( Oronbai         Boron         ホウ素) ],
+  6 => [ qw( Arboncai        Carbon        炭素) ],
+  7 => [ qw( Itrogennai      Nitrogen      窒素) ],
+  8 => [ qw( Xygenoai        Oxygen        酸素) ],
+  9 => [ qw( Luorinefai      Fluorine      フッ素) ],
+ 10 => [ qw( Eonnai          Neon          ネオン) ],
+ 11 => [ qw( Odiumsai        Sodium        ナトリウム) ],
+ 12 => [ qw( Agnesiummai     Magnesium     マグネシウム) ],
+ 13 => [ qw( Luminiumaai     Aluminium     アルミニウム) ],
+ 14 => [ qw( Iliconsai       Silicon       ケイ素) ],
+ 15 => [ qw( Hosphoruspai    Phosphorus    リン) ],
+ 16 => [ qw( Ulfursai        Sulfur        硫黄) ],
+ 17 => [ qw( Hlorinecai      Chlorine      塩素) ],
+ 18 => [ qw( Rgonaai         Argon         アルゴン) ],
+ 19 => [ qw( Otassiumpai     Potassium     カリウム) ],
+ 20 => [ qw( Alciumcai       Calcium       カルシウム) ],
+ 21 => [ qw( Candiumsai      Scandium      スカンジウム) ],
+ 22 => [ qw( Itaniumtai      Titanium      チタン) ],
+ 23 => [ qw( Anadiumvai      Vanadium      バナジウム) ],
+ 24 => [ qw( Hromiumcai      Chromium      クロム) ],
+ 25 => [ qw( Anganesemai     Manganese     マンガン) ],
+ 26 => [ qw( Roniai          Iron          鉄) ],
+ 27 => [ qw( Obaltcai        Cobalt        コバルト) ],
+ 28 => [ qw( Ickelnai        Nickel        ニッケル) ],
+ 29 => [ qw( Oppercai        Copper        銅) ],
+ 30 => [ qw( Inczai          Zinc          亜鉛) ],
+ 31 => [ qw( Alliumgai       Gallium       ガリウム) ],
+ 32 => [ qw( Ermaniumgai     Germanium     ゲルマニウム) ],
+ 33 => [ qw( Rsenicaai       Arsenic       ヒ素) ],
+ 34 => [ qw( Eleniumsai      Selenium      セレン) ],
+ 35 => [ qw( Rominebai       Bromine       臭素) ],
+ 36 => [ qw( Ryptonkai       Krypton       クリプトン) ],
+ 37 => [ qw( Ubidiumrai      Rubidium      ルビジウム) ],
+ 38 => [ qw( Trontiumsai     Strontium     ストロンチウム) ],
+ 39 => [ qw( Ttriumyai       Yttrium       イットリウム) ],
+ 40 => [ qw( Irconiumzai     Zirconium     ジルコニウム) ],
+ 41 => [ qw( Iobiumnai       Niobium       ニオブ) ],
+ 42 => [ qw( Olybdenummai    Molybdenum    モリブデン) ],
+ 43 => [ qw( Echnetiumtai    Technetium    テクネチウム) ],
+ 44 => [ qw( Utheniumrai     Ruthenium     ルテニウム) ],
+ 45 => [ qw( Hodiumrai       Rhodium       ロジウム) ],
+ 46 => [ qw( Alladiumpai     Palladium     パラジウム) ],
+ 47 => [ qw( Ilversai        Silver        銀) ],
+ 48 => [ qw( Admiumcai       Cadmium       カドミウム) ],
+ 49 => [ qw( Ndiumiai        Indium        インジウム) ],
+ 50 => [ qw( Intai           Tin           スズ) ],
+ 51 => [ qw( Ntimonyaai      Antimony      アンチモン) ],
+ 52 => [ qw( Elluriumtai     Tellurium     テルル) ],
+ 53 => [ qw( Odineiai        Iodine        ヨウ素) ],
+ 54 => [ qw( Enonxai         Xenon         キセノン) ],
+ 55 => [ qw( Esiumcai        Cesium        セシウム) ],
+ 56 => [ qw( Ariumbai        Barium        バリウム) ],
+ 57 => [ qw( Anthanumlai     Lanthanum     ランタン) ],
+ 58 => [ qw( Eriumcai        Cerium        セリウム) ],
+ 59 => [ qw( Raesodymiumpai  Praseodymium  プラセオジム) ],
+ 60 => [ qw( Eodymiumnai     Neodymium     ネオジム) ],
+ 61 => [ qw( Romethiumpai    Promethium    プロメチウム) ],
+ 62 => [ qw( Amariumsai      Samarium      サマリウム) ],
+ 63 => [ qw( Uropiumeai      Europium      ユウロピウム) ],
+ 64 => [ qw( Adoliniumgai    Gadolinium    ガドリニウム) ],
+ 65 => [ qw( Erbiumtai       Terbium       テルビウム) ],
+ 66 => [ qw( Ysprosiumdai    Dysprosium    ジスプロシウム) ],
+ 67 => [ qw( Olmiumhai       Holmium       ホルミウム) ],
+ 68 => [ qw( Rbiumeai        Erbium        エルビウム) ],
+ 69 => [ qw( Huliumtai       Thulium       ツリウム) ],
+ 70 => [ qw( Tterbiumyai     Ytterbium     イッテルビウム) ],
+ 71 => [ qw( Utetiumlai      Lutetium      ルテチウム) ],
+ 72 => [ qw( Afniumhai       Hafnium       ハフニウム) ],
+ 73 => [ qw( Antalumtai      Tantalum      タンタル) ],
+ 74 => [ qw( Ungstentai      Tungsten      タングステン) ],
+ 75 => [ qw( Heniumrai       Rhenium       レニウム) ],
+ 76 => [ qw( Smiumoai        Osmium        オスミウム) ],
+ 77 => [ qw( Ridiumiai       Iridium       イリジウム) ],
+ 78 => [ qw( Latinumpai      Platinum      白金) ],
+ 79 => [ qw( Oldgai          Gold          金) ],
+ 80 => [ qw( Ercurymai       Mercury       水銀) ],
+ 81 => [ qw( Halliumtai      Thallium      タリウム) ],
+ 82 => [ qw( Eadlai          Lead          鉛) ],
+ 83 => [ qw( Ismuthbai       Bismuth       ビスマス) ],
+ 84 => [ qw( Oloniumpai      Polonium      ポロニウム) ],
+ 85 => [ qw( Statineaai      Astatine      アスタチン) ],
+ 86 => [ qw( Adonrai         Radon         ラドン) ],
+ 87 => [ qw( Ranciumfai      Francium      フランシウム) ],
+ 88 => [ qw( Adiumrai        Radium        ラジウム) ],
+ 89 => [ qw( Ctiniumaai      Actinium      アクチニウム) ],
+ 90 => [ qw( Horiumtai       Thorium       トリウム) ],
+ 91 => [ qw( Rotactiniumpai  Protactinium  プロトアクチニウム) ],
+ 92 => [ qw( Raniumuai       Uranium       ウラン) ],
+ 93 => [ qw( Eptuniumnai     Neptunium     ネプツニウム) ],
+ 94 => [ qw( Lutoniumpai     Plutonium     プルトニウム) ],
+ 95 => [ qw( Mericiumaai     Americium     アメリシウム) ],
+ 96 => [ qw( Uriumcai        Curium        キュリウム) ],
+ 97 => [ qw( Erkeliumbai     Berkelium     バークリウム) ],
+ 98 => [ qw( Aliforniumcai   Californium   カリホルニウム) ],
+ 99 => [ qw( Insteiniumeai   Einsteinium   アインスタイニウム) ],
+100 => [ qw( Ermiumfai       Fermium       フェルミウム) ],
+101 => [ qw( Endeleviummai   Mendelevium   メンデレビウム) ],
+102 => [ qw( Obeliumnai      Nobelium      ノーベリウム) ],
+103 => [ qw( Awerenciumlai   Lawrencium    ローレンシウム) ],
 104 => [ qw( Utherfordiumrai Rutherfordium ラザホージウム) ],
-105 => [ qw( Ubniumdai Dubnium ドブニウム) ],
-106 => [ qw( Eaborgiumsai Seaborgium シーボーギウム) ],
-107 => [ qw( Ohriumbai Bohrium ボーリウム) ],
-108 => [ qw( Assiumhai Hassium ハッシウム) ],
-109 => [ qw( Eitneriummai Meitnerium マイトネリウム) ],
-110 => [ qw( Armstadtiumdai Darmstadtium ) ],
-111 => [ qw( Oentgeniumrai Roentgenium ) ],
-112 => [ qw( Operniciumcai Copernicium ) ],
-113 => [ qw( Ihoniumnai Nihonium ) ],  # Nihonium (Nh)
-114 => [ qw( Leroviumfai Flerovium ) ],
-115 => [ qw( Oscoviummai Moscovium ) ], # Moscovium (Mc)
-116 => [ qw( Ivermoriumlai Livermorium ) ],
-117 => [ qw( Ennessinetai Tennessine ) ], # Tennessine (Ts)
-118 => [ qw( Ganessonoai Oganesson ) ], # Oganesson (Og)
+105 => [ qw( Ubniumdai       Dubnium       ドブニウム) ],
+106 => [ qw( Eaborgiumsai    Seaborgium    シーボーギウム) ],
+107 => [ qw( Ohriumbai       Bohrium       ボーリウム) ],
+108 => [ qw( Assiumhai       Hassium       ハッシウム) ],
+109 => [ qw( Eitneriummai    Meitnerium    マイトネリウム) ],
+110 => [ qw( Armstadtiumdai  Darmstadtium  ダームスタチウム) ],
+111 => [ qw( Oentgeniumrai   Roentgenium   レントゲニウム) ],
+112 => [ qw( Operniciumcai   Copernicium   コペルニシウム) ],
+113 => [ qw( Ihoniumnai      Nihonium      ニホニウム) ],
+114 => [ qw( Leroviumfai     Flerovium     フレロビウム) ],
+115 => [ qw( Oscoviummai     Moscovium     モスコビウム) ],
+116 => [ qw( Ivermoriumlai   Livermorium   リバモリウム) ],
+117 => [ qw( Ennessinetai    Tennessine    テネシン) ],
+118 => [ qw( Ganessonoai     Oganesson     オガネソン) ],
 );
 
 {
